@@ -629,7 +629,7 @@ PARSE_TEXT_CASE = [
                     "cloud_type": None,
                 },
             ],
-            "weather": ["In the Vicinity Showers of"],
+            "weather": ["Showers in the Vicinity"],
             "auto": False,
         },
     },
@@ -662,4 +662,103 @@ PARSE_TEXT_CASE = [
             "weather": ["Clear Sky"],
         },
     },
+    {
+        "kwargs": {
+            "text": "METAR RCNN 091100Z 20003KT 9999 VCSH FEW010 BKN040 29/25 Q1010 RMK A2984 VCSH W=",
+            "year": 2024,
+            "month": 10,
+        },
+        "result": {
+            "kind": "METAR",
+            "icao": "RCNN",
+            "auto": False,
+            "datetime": "2024-10-09T11:00:00+00:00",
+            "wind_direction": 200,
+            "wind_direction_units": "degree",
+            "wind_speed": 1,
+            "wind_speed_units": "m/s",
+            "gust": None,
+            "wind_direction_range": None,
+            "visibility": 99999,
+            "visibility_units": "m",
+            "cavok": False,
+            "temperature": 29,
+            "dew_temperature": 25,
+            "temperature_units": "degree C",
+            "qnh": 1010,
+            "qnh_units": "hPa",
+            "cloud": [
+                {
+                    "cloud_mask": 0.75,
+                    "cloud_height": 800,
+                    "cloud_height_units": "m",
+                    "cloud_type": None,
+                },
+                {
+                    "cloud_mask": 0.25,
+                    "cloud_height": 200,
+                    "cloud_height_units": "m",
+                    "cloud_type": None,
+                },
+            ],
+            "weather": ["Showers in the Vicinity"],  # Only one, RMK content is ignored
+        },
+    },
+    {
+        "kwargs": {
+            "text": "METAR RCNN 092130Z 30003KT 6000 -RA VCTS FEW008 FEW012CB BKN016 BKN040 27/26 Q1009 BECMG FM2200 TL2300 TSRA RMK A2980 TS SW MOV N=",
+            "year": 2024,
+            "month": 10,
+        },
+        "result": {
+            "kind": "METAR",
+            "icao": "RCNN",
+            "auto": False,
+            "datetime": "2024-10-09T21:30:00+00:00",
+            "wind_direction": 300,
+            "wind_direction_units": "degree",
+            "wind_speed": 1,
+            "wind_speed_units": "m/s",
+            "gust": None,
+            "wind_direction_range": None,
+            "visibility": 6000,
+            "visibility_units": "m",
+            "cavok": False,
+            "temperature": 27,
+            "dew_temperature": 26,
+            "temperature_units": "degree C",
+            "qnh": 1009,
+            "qnh_units": "hPa",
+            "cloud": [
+                {
+                    "cloud_mask": 0.75,
+                    "cloud_height": 320,
+                    "cloud_height_units": "m",
+                    "cloud_type": None,
+                },
+                {
+                    "cloud_mask": 0.75,
+                    "cloud_height": 800,
+                    "cloud_height_units": "m",
+                    "cloud_type": None,
+                },
+                {
+                    "cloud_mask": 0.25,
+                    "cloud_height": 160,
+                    "cloud_height_units": "m",
+                    "cloud_type": None,
+                },
+                {
+                    "cloud_mask": 0.25,
+                    "cloud_height": 240,
+                    "cloud_height_units": "m",
+                    "cloud_type": "cumulonimbus",
+                },
+            ],
+            "weather": [
+                "Light Rain",
+                "Thunderstorm in the Vicinity",
+            ],  # VCTS with new word order, RMK ignored
+        },
+    },
 ]
